DequeOnce

Struct DequeOnce 

pub struct DequeOnce { /* private fields */ }
This queue mode removes all entries from the queue that have timed out.

The further behaviour is defined by the type of the deque.

Implementations

Source

impl DequeOnce

pub fn new(absolute_timeout: impl Into<AbsoluteTime>) -> Self

Creates new instacne.