pub struct DequePeriodic { /* private fields */ }Expand description
This queue mode does not remove an element that has timed out (by absolute_timeout),
but extends (by relative_period) the timeout and returns the element back to the queue.
Implementations
Sourceimpl DequePeriodic
impl DequePeriodic
Sourcepub fn new_from_now(rel_time: impl Into<RelativeTime>) -> Self
pub fn new_from_now(rel_time: impl Into<RelativeTime>) -> Self
Creates new instance. The relative_time is not added to
absolute_time until timeout. The values are unchecked at this
point and will be checked during placement in queue.
Sourcepub fn new(
abs_time: impl Into<AbsoluteTime>,
rel_time: impl Into<RelativeTime>,
) -> Self
pub fn new( abs_time: impl Into<AbsoluteTime>, rel_time: impl Into<RelativeTime>, ) -> Self
Creates new instance with the initial timeout abs_time and
period rel_time which is added to the abs_time each time
the timeout occures. The values are unchecked at this
point and will be checked during placement in queue.