TimerDequeTicket

Struct TimerDequeTicket 

pub struct TimerDequeTicket { /* private fields */ }
A ticket which is issued to the caller. If TimerDequeTicket is dropped, the Weak reference to Arc will no longer be valid and the timer would ignore the instance and remove it from the queue independeltly from the deque operation mode.

Implementations