TimerDequeTicketIssuer

Struct TimerDequeTicketIssuer 

pub struct TimerDequeTicketIssuer<MODE>{ /* private fields */ }
A type of deque which issues a tickets TimerDequeTicket which contains a TimerDequeId - a uniq number of the ticket. On timeout, the TimerDequeId is returned to indentify the timeout source.

Generics

MODE - a OrderedTimerDequeMode defines the deque behaviour. There are two types of the operation:

  • After timeout the element is removed from the queue.

  • After timeout the element timeout is extended automatically until the item removed from the queue manually.

Examples

let mut time_list = 
    OrderedTimerDeque
        ::<DequeOnce, TimerDequeTicketIssuer<_>>
        ::new("test_label1".into(), 4, false, true)
           .unwrap();

or

let mut time_list = 
    OrderedTimerDeque
        ::<DequePeriodic, TimerDequeTicketIssuer<_>>
        ::new("test_label1".into(), 4, false, true)
           .unwrap();