A ticket which is assigned to specific task in order to send the same task to the same
thread which has been already assigned. If only one thread is allocated, then this is not
really necessary (will be optimized in future).
An instance which is returned by the SyncPeriodicTasks::add whuch guards the
task and allows to control its state. If task is no longer needed the instance
can be dropped and it will be removed from the system.
A instance which contains all information about the threads allocated for the
task execution, tasks and timer polling. An instance is shared with all threads.
Programs the taks’s timer to specific time and mode. This instance is
a wrapper around the TimerExpMode as this struct requers the generic to
be specified which defines the type of the time.