pub enum PeriodicTaskTime {
Absolute(TimerExpMode<AbsoluteTime>),
Relative(TimerExpMode<RelativeTime>),
}Expand description
Programs the taks’s timer to specific time and mode. This instance is a wrapper around the TimerExpMode as this struct requers the generic to be specified which defines the type of the time.
Variants
Absolute(TimerExpMode<AbsoluteTime>)
A provided time is absolute time in future.
Relative(TimerExpMode<RelativeTime>)
A provided time is relative to current time.
Implementations
Sourceimpl PeriodicTaskTime
impl PeriodicTaskTime
Sourcepub fn exact_time(abs_time: AbsoluteTime) -> Self
pub fn exact_time(abs_time: AbsoluteTime) -> Self
The timer is set to time up once and for the specific absolute time in future
(to current realclock time).
Sourcepub fn interval(rel_time: RelativeTime) -> Self
pub fn interval(rel_time: RelativeTime) -> Self
The timer is set to time up in the interval for the relative time.
Sourcepub fn interval_with_start_delay(
start_del_time: RelativeTime,
rel_int_time: RelativeTime,
) -> Self
pub fn interval_with_start_delay( start_del_time: RelativeTime, rel_int_time: RelativeTime, ) -> Self
The timer is set to time up in the interval for the relative time with the initial
delay.
Arguments
-
start_del_time- a RelativeTime of the initial delay. -
rel_int_time- a RelativeTime of the interval.