NewTaskTicket

Struct NewTaskTicket 

pub struct NewTaskTicket { /* private fields */ }
A ticket which is assigned to specific task in order to send the same task to the same thread which has been already assigned. If only one thread is allocated, then this is not really necessary (will be optimized in future).