PeriodicTaskGuard

Struct PeriodicTaskGuard 

pub struct PeriodicTaskGuard { /* private fields */ }
An instance which is returned by the SyncPeriodicTasks::add whuch guards the task and allows to control its state. If task is no longer needed the instance can be dropped and it will be removed from the system.

Implementations

Source

impl PeriodicTaskGuard

pub fn reschedule_task(&self, ptt: PeriodicTaskTime) -> TimerResult<()>

Requests the task rescheduling - changine the timer time or mode. The task is represented by the calling instance.

This function blocks the current thread for the maximum (in worst case) 5 seconds which is a timeout for feedback reception.

Arguments
  • ptt - a new time to be set to timer.
Returns

A Result as alias TimerResult is returned. In case if error is retuned, the operation should be considered as not completed correctly and the executor instance is poisoned i.e a bug happened.

The common errors may be retuned:

pub fn suspend_task(&self) -> TimerResult<()>

Requests to suspent the current task.

This function blocks the current thread for the maximum (in worst case) 5 seconds which is a timeout for feedback reception.

Returns

A Result as alias TimerResult is returned.

In case if error is retuned, the operation should be considered as not completed correctly and the executor instance is poisoned i.e a bug happened.

The common errors may be retuned:

pub fn resume_task(&self) -> TimerResult<()>

Requests to resume the task from the suspend state.

This function blocks the current thread for the maximum (in worst case) 5 seconds which is a timeout for feedback reception.

Returns

A Result as alias TimerResult is returned.

In case if error is retuned, the operation should be considered as not completed correctly and the executor instance is poisoned i.e a bug happened.

The common errors may be retuned: