pub struct SharedPeriodicTasks { /* private fields */ }Expand description
A instance which contains all information about the threads allocated for the task execution, tasks and timer polling. An instance is shared with all threads.