TimerFdInternal

Struct TimerFdInternal 

pub struct TimerFdInternal { /* private fields */ }
A synchronious timer instance based on the Linux’s timerfd_create.

A EPoll or select can be used to monitor the instance. Also the instance implements Future which can be polled from async code. Or used with tokio’s AsyncFd or any other equivalent.

It can be used with provided poll.rs event notification system wrapper.