Module poll

Module poll 

A common code for timer polling.

Re-exports

pub use super::linux::timer_poll::TimerEventWatch;

Structs

PollInterrupt
PollInterruptAq
PolledTimerFd
A wrapper which provides a funtionality for the TimerPoll.
TimerPoll
A main instance which initializes the event listeners from the registered timers.

Enums

PollEventType
A poll result.

Traits

TimerPollOps
A standart functions for each timer.

Type Aliases

DefaultEventWatch