PolledTimerFd

Struct PolledTimerFd 

pub struct PolledTimerFd<T: FdTimerMarker> { /* private fields */ }
A wrapper which provides a funtionality for the TimerPoll.

A TimerFd should be wrapped into this instance and a poll instance is attached during wrapping.

By calling drop, the timer is automatically removed from the poller and timer will be destructed too. The same situation happens if [SyncTimerFd::detach_timer] is called, but the timer instance is returned.

Implementations

Source

impl<T: FdTimerMarker> PolledTimerFd<T>

pub fn detach_timer(self) -> Result<T, Self>

Removes the timer from the poll instance and releases the timer instance.

In case, if it is not possible to relese the timer, the Result::Err is returnes with Self. Otherwise, a T is returned.

pub fn is_poll_valid(&self) -> bool

Checks if poll instance still presents. It can not verify if poll operates normally. Just checks if current instance is attached to the instance which is valid.

pub fn get_inner(&self) -> &T

Returns the reference to the inner timer.

pub fn get_inner_mut(&mut self) -> &mut T