Module timer

Module timer 

A common code for the timer setup.

Structs

AbsoluteTime
An absolute time which are binded to the system’s clock and never be zero except when timer is reset.
RelativeTime
A relative time i.e time which is not binded to the system’s clock.
TimerFd
A common abstract type for the timer which is a main instance.
TimerId
A unified timer identification instance which can be used to identify the timers.

Enums

TimerExpMode
A timer expiry modes. Not every OS supports every mode. Read comments for the OS specific timer. For the nanoseconds param the max value is 999_999_999 for most OSes.
TimerReadRes
A timer FD read operation result.

Traits

AsTimerId
A trait which provides a standart interface to aquire the TimerId which is a unification of the timer instance identification.
FdTimerCom
A common trait which is implemented by all timer realizationss for different OSes.
FdTimerMarker
A super trait which implements a marker for the timer poll subsystem.
FdTimerRead
A super trait which is used on timers for executing the reading code of the timer.
ModeTimeType
A super trait which defines a standart interface for the different time types i.e