pub enum TimerReadRes<T: Sized + Debug + Display + Clone + Eq + PartialEq> {
Ok(T),
Cancelled,
WouldBlock,
}Expand description
A timer FD read operation result.
Variants
Ok(T)
Read successfull.
Cancelled
TFD_TIMER_ABSTIME
Marks this timer as cancelable if the real-time clock under‐ goes a discontinuous change (settimeofday(2), clock_settime(2), or similar). When such changes occur, a current or future read(2) from the file descriptor will fail with the error ECANCELED.
This is not appliciable for Kqeueue BSD timer and Windows.
WouldBlock
EAGAIN If FD is nonblocking then this will be returned.
Implementations