pub struct RelativeTime { /* private fields */ }Expand description
Implementations
Sourceimpl RelativeTime
impl RelativeTime
Sourcepub fn new_time(time_sec: i64, time_nsec: i64) -> Self
pub fn new_time(time_sec: i64, time_nsec: i64) -> Self
Creates new instance for relative time accepting the user input.
Automatically corrects the time_nsec value if it is larger than
999_999_999ns.
Arguments
time_sec - i64 a seconds in relative notation.
time_nsec - i64 nanoseconds of relative seconds value. Should not be
larger than 999_999_999 which is defined by const Self::MAX_NS. In
case if it is larger, the nsec will be rounded and an extra secons
will be added.
pub fn is_zero(&self) -> bool