FdTimerRead

Trait FdTimerRead 

pub trait FdTimerRead:
    UnixFd
    + Display
    + AsRef<str>
    + PartialEq<str>
    + AsTimerId {
    // Required method
    fn read(&self) -> TimerPortResult<TimerReadRes<u64>>;
}
A super trait which is used on timers for executing the reading code of the timer.

Traits

Required Methods

fn read(&self) -> TimerPortResult<TimerReadRes<u64>>

Attempts to read the timer. The realization is different on different OS. The main purpose is to check if timer is ready (ended).

Returns

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors