Module unix

Module unix 

All portable code for OS in unix family.

Re-exports

pub use linux::timer_poll::TimerEventWatch;
pub use linux::timer_fd_linux::TimerFdInternal;
pub use nix::libc;

Modules

linux

Structs

BorrowedFd
A borrowed file descriptor.
TimerFlags
Flags controling the type of the timer type.
TimerSetTimeFlags
A bit mask that can include the values.
itimerspec
timespec

Enums

TimerType
A timer type

Constants

ECANCELED
EWOULDBLOCK

Traits

AsFd
A trait to borrow the file descriptor from an underlying object.
AsRawFd
A trait to extract the raw file descriptor from an underlying object.
UnixFd

Type Aliases

RawFd
Raw file descriptors.