pub struct DequeOnce { /* private fields */ }Expand description
This queue mode removes all entries from the queue that have timed out.
The further behaviour is defined by the type of the deque.
Implementations