TimerDequeConsumer

Struct TimerDequeConsumer 

pub struct TimerDequeConsumer<R, MODE>{ /* private fields */ }
This type of the queue consumes the instance for which the timer is set. The item must be Send and Clone, std::sync::Arc. This is convinient when it is required to store the instance in the timer and retrive it when the timeout happens. This method allows to avoid for lookups in the lists and working directly with the stored items.

Generics

R - an instance which should be stored on the timer dequeue. The instance must implement PartialEq, Eq, fmt::Debug, fmt::Display, Send.

MODE - a OrderedTimerDequeMode which defines the deque behaviour. There are two types of the operation:

  • [OrderdTimerDequeOnce] - after timeout the element is removed from the queue.

  • [OrderdTimerDequePeriodic] - after timeout the element timeout is extended until the item is not removed from the queue manually.

Example

let mut time_list = 
    OrderedTimerDeque
        ::<DequeOnce, TimerDequeConsumer<u64, _>>
        ::new("test_label1".into(), 4, false, true)
           .unwrap();

or

let mut time_list = 
    OrderedTimerDeque
        ::<DequePeriodic, TimerDequeConsumer<u64, _>>
        ::new("test_label1".into(), 4, false, true)
           .unwrap();