A ticket issuer. Issues a ticket which should be assigned to the instance whcih was added
to the timer’s queue. The ticket can be used to remove the item from queue before the
timeout event. If ticket is dropped i.e connection closed, the ticket will be
in timer’s queue until timeout where it will be ignored on timeout event.
Structs
- Timer
Deque Ticket - A ticket which is issued to the caller.
If
TimerDequeTicketis dropped, the Weak reference to Arc will no longer be valid and the timer would ignore the instance and remove it from the queue independeltly from the deque operation mode. - Timer
Deque Ticket Issuer - A type of deque which issues a
ticketsTimerDequeTicket which contains a TimerDequeId - a uniq number of the ticket. On timeout, the TimerDequeId is returned to indentify the timeout source.