OrderedTimerDequeInterf

Trait OrderedTimerDequeInterf 

pub trait OrderedTimerDequeInterf<MODE: OrderedTimerDequeMode> {
    // Required method
    fn get_timeout_absolute(&self) -> AbsoluteTime;
}
A trait which is used by the base OrderTimerDeque. This is an interface which provides access to the timeout value of the instance.

Required Methods

fn get_timeout_absolute(&self) -> AbsoluteTime

Returns the absolute time and the timer mode.

Implementors