pub enum PeriodicTaskResult {
Ok,
CancelTask,
TaskReSchedule(PeriodicTaskTime),
}Expand description
A result of the task execution which is returned by the user task. See description for the each variant.
Variants
Ok
The task exec was ok. No errors.
CancelTask
Cancels (but not removing) the task due to error or for other reason.
By returning this result the timer is unset to stop generating events.
But, if since the AbortTask was received and a timer has timed out again
the event will be called again. It is not necessary to return the AbortTask again,
just return PeriodicTaskResult::Ok exiting imidiatly.
TaskReSchedule(PeriodicTaskTime)
A request to reschedule the task to a new time or interval. The 0 argument
should contain new time. The timer mode can be changed.