A common code for timer polling.
Re-exports
pub use super::linux::timer_poll::TimerEventWatch;
Structs
- Poll
Interrupt - Poll
Interrupt Aq - Polled
Timer Fd - A wrapper which provides a funtionality for the TimerPoll.
- Timer
Poll - A main instance which initializes the event listeners from the registered timers.
Enums
- Poll
Event Type - A
pollresult.
Traits
- Timer
Poll Ops - A standart functions for each timer.