TimerPoll

Struct TimerPoll 

pub struct TimerPoll(/* private fields */);
A main instance which initializes the event listeners from the registered timers.

Implementations

Source

impl TimerPoll

pub fn new() -> TimerResult<Self>

Creates new instance of the event listener.

pub fn add<T: FdTimerMarker>(&self, timer: T) -> TimerResult<PolledTimerFd<T>>

Adds the timer to the event monitor. It accepts any reference to instance which implements AsFd and it is not limited specificly to timers. Maybe later this behaviour will me modified.

Arguments
  • timer - T where impl [AsTimerFd] a timer instance. The provided FD will be polled for [EpollFlags::EPOLLIN] event types. The FD of the timer should be inited as non-blocking, but if it is not, the function attepts to switch the mode. It will not be restored when the timer will be removed from Self.
Returns

A TimerResult i.e Result is returned with error description in case of error.

pub fn poll( &self, timeout: Option<i32>, ) -> TimerResult<Option<Vec<PollEventType>>>

Polls the event monitor for events. Depending on the timeout the behaviour will be different.

Arguments
  • timeout - poll timeout. If set to Option::None will block the current thread. If set to Option::Some with inner value 0 will return immidiatly. The timeout is set in miliseconds.
Returns

A TimerResult i.e Result is returned with

pub fn get_poll_interruptor(&self) -> PollInterrupt

pub fn interrupt_poll(&self) -> bool