A common code for the timer setup.
Re-exports
pub use super::linux::timer_fd_linux::TimerFdInternal;
Structs
- Absolute
Time - An
absolutetime which are binded to the system’s clock and never be zero except when timer is reset. - Relative
Time - A
relativetime i.e time which is not binded to the system’s clock. - TimerFd
- A common abstract type for the timer which is a main instance.
- Timer
Flags - Flags controling the type of the timer type.
- Timer
SetTime Flags - A bit mask that can include the values.
- itimerspec
- timespec
Enums
- Timer
ExpMode - A timer expiry modes. Not every OS supports
every mode. Read comments for the OS specific
timer. For the
nanosecondsparam the max value is 999_999_999 for most OSes. - Timer
Read Res - A timer FD read operation result.
- Timer
Type - A timer type
Traits
- FdTimer
Com - A common trait which is implemented by all timer realizationss for different OSes.
- FdTimer
Marker - A super trait which implements a marker for the
timer pollsubsystem. - FdTimer
Read - A super trait which is used on timers for executing the reading code of the timer.
- Mode
Time Type - A super trait which defines a standart interface for the different time types i.e