pub struct TimerFd(/* private fields */);Expand description
A common abstract type for the timer which is a main instance.
Implements
This instance implements:
-
[TimerFdMioCompat] and [mio::event::Source] - if the
feature = enable_mio_compatis enabled.
Multithread
A MT-safe, read-only. MT-access is implemented on OS level, so no mutexes or other sync is implemented.
Poll
-
A built-in crate::TimerPoll can be used.
-
An external crate MIO [TimerFdMioCompat] if
feature = enable_mio_compatis enabled. -
User implemented poll. The FD can be aquired via AsRawFd AsFd.
Async
A Future is implemented.
Examples
ⓘ
let timer =
TimerFd::new(Cow::Borrowed("test"), TimerType::CLOCK_REALTIME,
TimerFlags::empty()).unwrap();
timer Implementations
Sourceimpl TimerFd
impl TimerFd
pub fn new( label: Cow<'static, str>, timer_type: TimerType, timer_flags: TimerFlags, ) -> TimerPortResult<Self>
Sourcepub fn get_timer(&self) -> &TimerFdInternal ⓘ
pub fn get_timer(&self) -> &TimerFdInternal ⓘ
Borrows non-muntable reference to the timer. A Deref is implemented for this purpose, but the function was left for compat.