AsTimerId

Trait AsTimerId 

pub trait AsTimerId {
    // Required method
    fn as_timer_id(&self) -> TimerId;
}
A trait which provides a standart interface to aquire the TimerId which is a unification of the timer instance identification.

Implementations

A sub-trait of FdTimerRead.

Required Methods

fn as_timer_id(&self) -> TimerId

Returns the uniq timer ID number.

Implementors