FdTimerMarker

Trait FdTimerMarker 

pub trait FdTimerMarker:
    FdTimerRead
    + Eq
    + PartialEq {
    // Required methods
    fn clone_timer(&self) -> TimerFd ;
    fn get_strong_count(&self) -> usize;
}
A super trait which implements a marker for the timer poll subsystem.

Traits

  • FdTimerRead - a sub trait which is a super trait which includes user sub-traits.

Required Methods

fn clone_timer(&self) -> TimerFd

Clones the instance of the timer.

fn get_strong_count(&self) -> usize

Returns the count of strong references to inner type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors