pub trait FdTimerMarker:
FdTimerRead
+ Eq
+ PartialEq {
// Required methods
fn clone_timer(&self) -> TimerFd ⓘ;
fn get_strong_count(&self) -> usize;
}Expand description
A super trait which implements a marker for the timer poll subsystem.
Traits
- FdTimerRead - a sub trait which is a super trait which includes user sub-traits.
Required Methods
fn clone_timer(&self) -> TimerFd ⓘ
fn get_strong_count(&self) -> usize
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.