FdTimerRead

Trait FdTimerRead 

pub trait FdTimerRead:
    AsFd
    + AsRawFd
    + Display
    + AsRef<str>
    + PartialEq<str>
    + PartialEq<RawFd> {
    // Required method
    fn read(&self) -> TimerPortResult<TimerReadRes<u64>>;
}
A super trait which is used on timers for executing the reading code of the timer.

Traits

Required Methods

fn read(&self) -> TimerPortResult<TimerReadRes<u64>>

Attempts to read the timer. The realization is different on different OS. The main purpose is to check if timer is ready (ended).

Returns

Implementors